import fs from "fs";
import { curry, join, keys, nth, map, values } from "ramda";
/**
 * Synchronously writes a dataframe to a CSV file.
 *
 * @func
 * @memberOf Z
 * @category IO
 * @param {df} df Zebras dataframe to write
 * @param {String} filepath File path for the CSV file to write
 * @return {undefined}
 * @example
 *
 * Z.toCSV(filepath, df)
 */

var toCSV = curry(function (filepath, df) {
  try {
    var headers = join(",", keys(nth(0, df)));
    var rows = map(values, df);
    var rowStrings = join("\n", map(join(","), rows));
    fs.writeFileSync(filepath, "".concat(headers, "\n").concat(rowStrings));
    return df;
  } catch (error) {
    return error;
  }
});
export default toCSV;